# Modules-Box {{name}}


## Description
{{description}}

## Use 
To install the required dependencies:
```shell
yarn 
```
To build for development:
```shell
yarn build:dev
```
To build for production:
```shell
yarn build:prod
```

To test:
```shell
yarn test
```

## Hello newcomers :)

**This section is for the developers starting to create their modules-box.
You should remove this section when publishing your package. 
It refers to the provided modules as example when the pack is generated.**

### Creating a module

### Adding view to a module

### Creating module's plugins

### About dependencies management: CDN or not CDN

